TWall
=====

TWall is a simple application to display tweets returned by the
`Twitter's Search API <https://dev.twitter.com/rest/public/search>`_. You can run it from the command line to watch
newly added tweets in near real-time, or launch a simple web application on your machine that mirrors Twitter's search
feature. It supports all three modes of search offered by the API: recent, popular and mixed.

Developed for MI-PYT 2016/2017


Contents of TWall's Documentation
=================================

.. toctree::
   :maxdepth: 4

   introduction
   usage_in_code
   modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Authors
=======

TWall is developed and maintained by `Daniel Maly <https://github.com/DanielMaly>`_


License
=======

`MIT <https://opensource.org/licenses/MIT>`_
